RequestProcessor

Struct RequestProcessor 

pub struct RequestProcessor<'pw, F, Req>
where F: Facilitator, Req: HttpRequest,
{ pub paywall: &'pw PayWall<F>, pub request: Req, pub payload: PaymentPayload, pub selected: PaymentRequirements, pub payment_state: PaymentState, }
Payment processing state before running the resource handler.

See PayWall for usage in the full payment processing flow.

Fields

paywall: &'pw PayWall<F>request: Reqpayload: PaymentPayloadselected: PaymentRequirementspayment_state: PaymentState

Implementations

Source

impl<'pw, F, Req> RequestProcessor<'pw, F, Req>
where F: Facilitator, Req: HttpRequest,

pub async fn verify( self, ) -> Result<RequestProcessor<'pw, F, Req>, ErrorResponse>

Verify the payment with the facilitator.

self.payment_state.verified will be populated on success.

pub async fn settle( self, ) -> Result<RequestProcessor<'pw, F, Req>, ErrorResponse>

Settle the payment with the facilitator.

self.payment_state.settled will be populated on success.

pub async fn run_handler<Fun, Fut, Res>( self, handler: Fun, ) -> Result<ResponseProcessor<'pw, F, Res>, ErrorResponse>
where Fun: FnOnce(Req) -> Fut, Fut: Future<Output = Res>,

Run the resource handler with the payment state attached to the request extensions.

After running the handler, returns a ResponseProcessor for further processing.