pub struct ResponseProcessor<'pw, F, Res>where
F: Facilitator,{
pub paywall: &'pw PayWall<F>,
pub response: Res,
pub payload: PaymentPayload,
pub selected: PaymentRequirements,
pub payment_state: PaymentState,
}Expand description
Payment processing state after running the resource handler.
Fields
paywall: &'pw PayWall<F>response: Respayload: PaymentPayloadselected: PaymentRequirementspayment_state: PaymentStateImplementations
Sourceimpl<'pw, F, Res> ResponseProcessor<'pw, F, Res>where
F: Facilitator,
Res: HttpResponse,
impl<'pw, F, Res> ResponseProcessor<'pw, F, Res>where
F: Facilitator,
Res: HttpResponse,
Sourcepub async fn settle(
self,
) -> Result<ResponseProcessor<'pw, F, Res>, ErrorResponse>
pub async fn settle( self, ) -> Result<ResponseProcessor<'pw, F, Res>, ErrorResponse>
Settle the payment with the facilitator after running the resource handler.
After settlement, self.payment_state.settled will be populated on success.
Sourcepub async fn settle_on(
self,
predicate: impl Fn(&Res) -> bool,
) -> Result<ResponseProcessor<'pw, F, Res>, ErrorResponse>
pub async fn settle_on( self, predicate: impl Fn(&Res) -> bool, ) -> Result<ResponseProcessor<'pw, F, Res>, ErrorResponse>
Conditionally settle the payment based on the provided prediction function.
After settlement, self.payment_state.settled will be populated on success.
Sourcepub async fn settle_on_success(
self,
) -> Result<ResponseProcessor<'pw, F, Res>, ErrorResponse>
pub async fn settle_on_success( self, ) -> Result<ResponseProcessor<'pw, F, Res>, ErrorResponse>
Settle the payment if the response status is a success (2xx).
After settlement, self.payment_state.settled will be populated on success.